// index.ts
import fs from "node:fs";
import { resolve } from "node:path";
import MagicString from "magic-string";
import process from "node:process";
function VitePluginAutoOptimizeDepsInclude(option = {}) {
  return {
    name: "update-optimizeDeps-include",
    apply: "serve",
    enforce: "pre",
    configureServer: (server) => {
      const originalWrite = process.stdout.write;
      const viteConfigPath = server.config.configFile || resolve(process.cwd(), "vite.config.ts");
      process.stdout.write = function(...args) {
        const r = originalWrite.apply(process.stdout, args);
        const str = args.at(0).toString().replace(/\x1B\[[0-9;]*m/g, "");
        handle(str);
        return r;
      };
      function handle(dependenciesStr) {
        const configContent = fs.readFileSync(viteConfigPath, "utf-8");
        const str = new MagicString(configContent);
        const start = findStartIndexAndIndent(configContent);
        const startIndex = start.index;
        const indent = start.indent;
        if (!startIndex) return;
        const data = dependenciesStr.match(option.regex || /new dependencies optimized:(.*)\n/);
        if (data) {
          const list = data[1].split(",").map((i) => i.trim());
          const current = findCurrentList(configContent.slice(startIndex));
          const currentList = current.list;
          const endIndex = current.index + startIndex;
          const newList = [.../* @__PURE__ */ new Set([...currentList, ...list])].filter(Boolean).sort((a, b) => a.length - b.length);
          const newStr = newList.reduce((pre, cur) => {
            return `${pre}${" ".repeat(indent + 2)}'${cur}',
`;
          }, "\n");
          str.update(startIndex, endIndex, newStr + " ".repeat(indent));
          server.watcher.unwatch(viteConfigPath);
          const { atime, mtime } = fs.statSync(viteConfigPath);
          fs.writeFileSync(viteConfigPath, str.toString());
          fs.utimesSync(viteConfigPath, atime, mtime);
          server.watcher.add(viteConfigPath);
        }
      }
      function findStartIndexAndIndent(parentStr) {
        const match = parentStr.match(/optimizeDeps:[\s\S]*?include:\s?\[/);
        if (!match) {
          return {
            index: 0,
            indent: 0
          };
        }
        return {
          index: match.index + match[0].length,
          indent: match[0].split("\n").pop().match(/^\s*/)[0].length
        };
      }
      function findCurrentList(parentStr) {
        for (let i = 0; i < parentStr.length; i++) {
          if (parentStr[i] === "]") {
            const str = parentStr.slice(0, i);
            return {
              list: str.split(",").map((i2) => i2.replace(/['"]/g, "").trim()),
              index: i
            };
          }
        }
        return {
          list: [],
          index: 0
        };
      }
    }
  };
}
var index_default = VitePluginAutoOptimizeDepsInclude;
export {
  index_default as default
};
